@@ -1,6 +1,6 @@
 import click
 from womg_core import womgc
-from womg.topic.lda import LDA_extended
+from womg.topic.lda_extended import LDA_extended
 from womg_core.utils.distributions import set_seed
 #from womg.utils.saver import TxtSaver
 
